==> torrentflux_2.1.orig.tar.gz: torrentflux_2.1/html/language/lang-english.php <==
<?php

/**************************************************************************/
/* TorrentFlux - PHP Torrent Client
/* ============================================
/*
/* This is the language file with all the system messages
/*
/* If you would like to make a translation, please email qrome@yahoo.com
/* the translated file. Please keep the original text order,
/* and just one message per line, also double check your translation!
/*
/* You need to change the second quoted phrase, not the capital one!
/*
/* If you need to use double quotes (") remember to add a backslash (\),
/* so your entry will look like: This is \"double quoted\" text.
/* And, if you use HTML code, please double check it.
/**************************************************************************/

define("_CHARSET","iso-8859-1");  // if you don't know... then leave this as is.
define("_SELECTFILE","Select a Torrent for upload");
define("_URLFILE","URL for the Torrent File");
define("_UPLOAD","Upload");
define("_GETFILE","Get File");
define("_TORRENTLINKS","Torrent Links");
define("_ONLINE","Online");
define("_OFFLINE","Offline");
define("_STORAGE","Storage");
define("_DRIVESPACE","Drive Space");
define("_SERVERSTATS","Server Stats / Who");
define("_DIRECTORYLIST","Directory List");
define("_ALL","All");
define("_PAGEWILLREFRESH","Page Will Refresh Every");
define("_SECONDS","Seconds");
define("_TURNONREFRESH","Turn ON Page Refresh");
define("_TURNOFFREFRESH","Turn OFF Page Refresh");
define("_WARNING","WARNING");
define("_DRIVESPACEUSED","Drive Space is used!");
define("_ADMINMESSAGE","You have a message from an administrator in your message box.");
define("_TORRENTS","Torrents");
define("_UPLOADHISTORY","Upload History");
define("_MYPROFILE","Edit My Profile");
define("_ADMINISTRATION","Administration");
define("_SENDMESSAGETO","Send a Message to");
define("_TORRENTFILE","Torrent File");
define("_FILESIZE","File Size");
define("_STATUS","Status");
define("_ADMIN","Admin");
define("_BADFILE","bad file");
define("_DATETIMEFORMAT","m/d/y g:i a"); //Date Time mask '02/26/04 03:53 pm'
define("_DATEFORMAT","m/d/y"); //Date mask '02/26/04'
define("_ESTIMATEDTIME","Estimated Time");
define("_DOWNLOADSPEED","Download Speed");
define("_UPLOADSPEED","Upload Speed");
define("_SHARING","Sharing");
define("_USER","User");
define("_DONE","DONE");
define("_INCOMPLETE","INCOMPLETE");
define("_NEW","NEW");
define("_TORRENTDETAILS","Torrent Details");
define("_STOPDOWNLOAD","Stop Torrent");
define("_RUNTORRENT","Run Torrent");
define("_SEEDTORRENT","Seed Torrent");
define("_DELETE","Delete");
define("_ABOUTTODELETE","You are about to delete");
define("_NOTOWNER","Not Owner of Torrent");
define("_MESSAGETOALL","This message was sent to ALL USERS");
define("_TRYDIFFERENTUSERID","Error: Try a different User ID.");
define("_HASBEENUSED","has been used.");
define("_RETURNTOEDIT","Return to Edit");
define("_ADMINUSERACTIVITY","Administration - User Activity");
define("_ADMIN_MENU","admin");
define("_ACTIVITY_MENU","activity");
define("_LINKS_MENU","links");
define("_NEWUSER_MENU","new user");
define("_BACKUP_MENU","backup");
define("_ALLUSERS","All Users");
define("_NORECORDSFOUND","NO RECORDS FOUND");
define("_SHOWPREVIOUS","Previous");
define("_SHOWMORE","Show More");
define("_ACTIVITYSEARCH","Activity Search");
define("_FILE","File");
define("_ACTION","Action");
define("_SEARCH","Search");
define("_ACTIVITYLOG","Activity Log - Last");
define("_DAYS","Days");
define("_IP","IP");
define("_TIMESTAMP","Time Stamp");
define("_USERDETAILS","User Details");
define("_HITS","Hits");
define("_UPLOADACTIVITY","Upload Activity");
define("_JOINED","Joined"); // header for the date when the user joined (became a member)
define("_LASTVISIT","Last Visit"); // header for when the user last visited the site
define("_USERSACTIVITY","Activity"); // used for popup to display Activity next to users name
define("_NORMALUSER","Normal User"); // used to describe a normal user's account type
define("_ADMINISTRATOR","Administrator"); // used to describe an administrator's account type
define("_SUPERADMIN","Super Admin"); // used to describe Super Admin's account type
define("_EDIT","Edit");
define("_USERADMIN","Administration - User Admin"); // title of page for user administration
define("_EDITUSER","Edit User");
define("_UPLOADPARTICIPATION","Upload Participation");
define("_UPLOADS","Uploads"); // Number of uploads a user has contributed
define("_PERCENTPARTICIPATION","Percent Participation");
define("_PARTICIPATIONSTATEMENT","Participation and Uploads based on the last"); // ends with 15 Days
define("_TOTALPAGEVIEWS","Total Page Views");
define("_THEME","Theme");
define("_USERTYPE","User Type");
define("_NEWPASSWORD","New Password");
define("_CONFIRMPASSWORD","Confirm Password");
define("_HIDEOFFLINEUSERS","Hide Offline Users on Home Page");
define("_UPDATE","Update");
define("_USERIDREQUIRED","User ID is required.");
define("_PASSWORDLENGTH","Password must have 6 or more characters.");
define("_PASSWORDNOTMATCH","Passwords do not match.");
define("_PLEASECHECKFOLLOWING","Please check the following"); // Displays errors after this statement
define("_NEWUSER","New User");
define("_PASSWORD","Password");
define("_CREATE","Create"); // button text to create a new user
define("_ADMINEDITLINKS","Administration - Edit Links");
define("_FULLURLLINK","Full URL Link");
define("_BACKTOPARRENT","Back Parent Directory");  // indicates going back to parent directory
define("_DOWNLOADDETAILS","Download Details");
define("_PERCENTDONE","Percent Done");
define("_RETURNTOTORRENTS","Return to Torrents"); // Link at the bottom of each page
define("_DATE","Date");
define("_WROTE","wrote");  // Used in a reply to tag what the user had writen
define("_SENDMESSAGETITLE","Send a Message");  // Title of page
define("_TO","To");
define("_FROM","From");
define("_YOURMESSAGE","Your Message");
define("_SENDTOALLUSERS","Send to All Users");
define("_FORCEUSERSTOREAD","Force User(s) to Read"); // Admin option in messaging
define("_SEND","Send");  // Button to send private message
define("_PROFILE","Profile");
define("_PROFILEUPDATEDFOR","Profile Updated for");  // Profile updated for 'username'
define("_REPLY","Reply");  // popup text for reply button
define("_MESSAGE","Message");
define("_MESSAGES","Messages");  // plural (more than one)
define("_RETURNTOMESSAGES","Return to Messages");
define("_COMPOSE","Compose");  // As in 'Compose a message' for button
define("_LANGUAGE","Language"); // label

define("_CURRENTDOWNLOAD","Current Download");
define("_CURRENTUPLOAD","Current Upload");
define("_SERVERLOAD","Server Load");
define("_FREESPACE","Free Space");
define("_UPLOADED", "Uploaded");

define("_QMANAGER_MENU","queue");
define("_SETTINGS_MENU","settings");
define("_SEARCHSETTINGS_MENU","search settings");
define("_ERRORSREPORTED","Errors");
define("_STARTED", "Started");
define("_ENDED", "Ended");
define("_QUEUED","Queued");
define("_DELQUEUE","Remove from Queue");
define("_FORCESTOP","Kill Torrent");
define("_STOPPING","Stopping");
define("_COOKIE_MENU","cookies");

?>

==> torrentflux_2.4.orig.tar.gz: torrentflux_2.4/html/language/lang-english.php <==
<?php

/**************************************************************************/
/* TorrentFlux - PHP Torrent Client
/* ============================================
/*
/* This is the language file with all the system messages
/*
/* If you would like to make a translation, please email qrome@yahoo.com
/* the translated file. Please keep the original text order,
/* and just one message per line, also double check your translation!
/*
/* You need to change the second quoted phrase, not the capital one!
/*
/* If you need to use double quotes (") remember to add a backslash (\),
/* so your entry will look like: This is \"double quoted\" text.
/* And, if you use HTML code, please double check it.
/**************************************************************************/

define("_CHARSET","iso-8859-1");  // if you don't know... then leave this as is.
define("_SELECTFILE","Select a Torrent for upload");
define("_URLFILE","URL for the Torrent File");
define("_UPLOAD","Upload");
define("_GETFILE","Get File");
define("_TORRENTLINKS","Torrent Links");
define("_ONLINE","Online");
define("_OFFLINE","Offline");
define("_STORAGE","Storage");
define("_DRIVESPACE","Drive Space");
define("_SERVERSTATS","Server Stats / Who");
define("_DIRECTORYLIST","Directory List");
define("_ALL","All");
define("_PAGEWILLREFRESH","Page Will Refresh In");
define("_SECONDS","Seconds");
define("_TURNONREFRESH","Turn ON Page Refresh");
define("_TURNOFFREFRESH","Turn OFF Page Refresh");
define("_WARNING","WARNING");
define("_DRIVESPACEUSED","Drive Space is used!");
define("_ADMINMESSAGE","You have a message from an administrator in your message box.");
define("_TORRENTS","Torrents");
define("_UPLOADHISTORY","Upload History");
define("_MYPROFILE","Edit My Profile");
define("_ADMINISTRATION","Administration");
define("_SENDMESSAGETO","Send a Message to");
define("_TORRENTFILE","Torrent File");
define("_FILESIZE","File Size");
define("_STATUS","Status");
define("_ADMIN","Admin");
define("_BADFILE","bad file");
define("_DATETIMEFORMAT","m/d/y g:i a"); //Date Time mask '02/26/04 03:53 pm'
define("_DATEFORMAT","m/d/y"); //Date mask '02/26/04'
define("_ESTIMATEDTIME","Estimated Time");
define("_DOWNLOADSPEED","Download Speed");
define("_UPLOADSPEED","Upload Speed");
define("_SHARING","Sharing");
define("_USER","User");
define("_DONE","DONE");
define("_INCOMPLETE","INCOMPLETE");
define("_NEW","NEW");
define("_TORRENTDETAILS","Torrent Details");
define("_STOPDOWNLOAD","Stop Torrent");
define("_RUNTORRENT","Run Torrent");
define("_SEEDTORRENT","Seed Torrent");
define("_DELETE","Delete");
define("_ABOUTTODELETE","You are about to delete");
define("_NOTOWNER","Not Owner of Torrent");
define("_MESSAGETOALL","This message was sent to ALL USERS");
define("_TRYDIFFERENTUSERID","Error: Try a different User ID.");
define("_HASBEENUSED","has been used.");
define("_RETURNTOEDIT","Return to Edit");
define("_ADMINUSERACTIVITY","Administration - User Activity");
define("_ADMIN_MENU","admin");
define("_ACTIVITY_MENU","activity");
define("_LINKS_MENU","links");
define("_NEWUSER_MENU","new user");
define("_BACKUP_MENU","backup");
define("_ALLUSERS","All Users");
define("_NORECORDSFOUND","NO RECORDS FOUND");
define("_SHOWPREVIOUS","Previous");
define("_SHOWMORE","Show More");
define("_ACTIVITYSEARCH","Activity Search");
define("_FILE","File");
define("_ACTION","Action");
define("_SEARCH","Search");
define("_ACTIVITYLOG","Activity Log - Last");
define("_DAYS","Days");
define("_IP","IP");
define("_TIMESTAMP","Time Stamp");
define("_USERDETAILS","User Details");
define("_HITS","Hits");
define("_UPLOADACTIVITY","Upload Activity");
define("_JOINED","Joined"); // header for the date when the user joined (became a member)
define("_LASTVISIT","Last Visit"); // header for when the user last visited the site
define("_USERSACTIVITY","Activity"); // used for popup to display Activity next to users name
define("_NORMALUSER","Normal User"); // used to describe a normal user's account type
define("_ADMINISTRATOR","Administrator"); // used to describe an administrator's account type
define("_SUPERADMIN","Super Admin"); // used to describe Super Admin's account type
define("_EDIT","Edit");
define("_USERADMIN","Administration - User Admin"); // title of page for user administration
define("_EDITUSER","Edit User");
define("_UPLOADPARTICIPATION","Upload Participation");
define("_UPLOADS","Uploads"); // Number of uploads a user has contributed
define("_PERCENTPARTICIPATION","Percent Participation");
define("_PARTICIPATIONSTATEMENT","Participation and Uploads based on the last"); // ends with 15 Days
define("_TOTALPAGEVIEWS","Total Page Views");
define("_THEME","Theme");
define("_USERTYPE","User Type");
define("_NEWPASSWORD","New Password");
define("_CONFIRMPASSWORD","Confirm Password");
define("_HIDEOFFLINEUSERS","Hide Offline Users on Home Page");
define("_UPDATE","Update");
define("_USERIDREQUIRED","User ID is required.");
define("_PASSWORDLENGTH","Password must have 6 or more characters.");
define("_PASSWORDNOTMATCH","Passwords do not match.");
define("_PLEASECHECKFOLLOWING","Please check the following"); // Displays errors after this statement
define("_NEWUSER","New User");
define("_PASSWORD","Password");
define("_CREATE","Create"); // button text to create a new user
define("_ADMINEDITLINKS","Administration - Edit Links");
define("_FULLURLLINK","Full URL Link");
define("_BACKTOPARRENT","Back Parent Directory");  // indicates going back to parent directory
define("_DOWNLOADDETAILS","Download Details");
define("_PERCENTDONE","Percent Done");
define("_RETURNTOTORRENTS","Return to Torrents"); // Link at the bottom of each page
define("_DATE","Date");
define("_WROTE","wrote");  // Used in a reply to tag what the user had writen
define("_SENDMESSAGETITLE","Send a Message");  // Title of page
define("_TO","To");
define("_FROM","From");
define("_YOURMESSAGE","Your Message");
define("_SENDTOALLUSERS","Send to All Users");
define("_FORCEUSERSTOREAD","Force User(s) to Read"); // Admin option in messaging
define("_SEND","Send");  // Button to send private message
define("_PROFILE","Profile");
define("_PROFILEUPDATEDFOR","Profile Updated for");  // Profile updated for 'username'
define("_REPLY","Reply");  // popup text for reply button
define("_MESSAGE","Message");
define("_MESSAGES","Messages");  // plural (more than one)
define("_RETURNTOMESSAGES","Return to Messages");
define("_COMPOSE","Compose");  // As in 'Compose a message' for button
define("_LANGUAGE","Language"); // label

define("_CURRENTDOWNLOAD","Current Download");
define("_CURRENTUPLOAD","Current Upload");
define("_SERVERLOAD","Server Load");
define("_FREESPACE","Free Space");
define("_UPLOADED", "Uploaded");

define("_QMANAGER_MENU","queue");
define("_SETTINGS_MENU","settings");
define("_SEARCHSETTINGS_MENU","search settings");
define("_ERRORSREPORTED","Errors");
define("_STARTED", "Started");
define("_ENDED", "Ended");
define("_QUEUED","Queued");
define("_DELQUEUE","Remove from Queue");
define("_FORCESTOP","Kill Torrent");
define("_STOPPING","Stopping");
define("_COOKIE_MENU","cookies");

?>
